<?php

namespace Bixo\ImportExport\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\ImportExport\Actions\ImportExportAction;
use Bixo\ImportExport\Http\Requests\ImportExportActionRequest;
use Bixo\ImportExport\Http\Resources\ImportExportResource;
use Bixo\ImportExport\Models\ImportExport;

/**
 * Admin web controller class.
 */
class ImportExportActionController extends BaseController
{

    /**
     * Action controller function for import_export.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ImportExportActionRequest $request, ImportExport $import_export, $action)
    {
        try {
            $request = $request->all();
            $import_export = ImportExportAction::run($action, $import_export, $request);

            $data = new ImportExportResource($import_export);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('import_export::import_export.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('import_export/import_export/' . $import_export->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('import_export/import_export/' . $import_export->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
