<?php

namespace Bixo\ImportExport\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\ImportExport\Actions\ImportExportExim;
use Bixo\ImportExport\Http\Requests\ImportExportEximRequest;

/**
 * Admin web controller class.
 */
class ImportExportEximController extends BaseController
{
    /**
     * Action controller function for import_export.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ImportExportEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = ImportExportExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('import_export:import_export.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('import_export/import_export/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('import_export/import_export/' . $exim))
                ->redirect();
        }
    }
}
