<?php

namespace Bixo\ImportExport\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\ImportExport\Http\Resources\ImportExportResource;
use Bixo\ImportExport\Http\Resources\ImportExportsCollection;
use Bixo\ImportExport\Scopes\ImportExportPublicScope;
use Bixo\ImportExport\Models\ImportExport;

class ImportExportPublicController extends BaseController
{

    /**
     * Show import_export's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = ImportExport::pushScope(new RequestScope())
            ->pushScope(new ImportExportPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $import_exports = new ImportExportsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('import_export::import_export.names'))
            ->view('import_export::public.import_export.index')
            ->data(compact('import_exports', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show import_export.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = ImportExport::findBySlug($slug);
        $data = new ImportExportResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('import_export::import_export.name'))
            ->view('import_export::public.import_export.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
