<?php

namespace Bixo\ImportExport\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\ImportExport\Forms\ImportExport as ImportExportForm;
use Bixo\ImportExport\Http\Requests\ImportExportResourceRequest;
use Bixo\ImportExport\Http\Resources\ImportExportResource;
use Bixo\ImportExport\Http\Resources\ImportExportsCollection;
use Bixo\ImportExport\Models\ImportExport;
use Bixo\ImportExport\Actions\ImportExportAction;
use Bixo\ImportExport\Actions\ImportExportActions;


/**
 * Resource controller class for import_export.
 */
class ImportExportResourceController extends BaseController
{

    /**
     * Initialize import_export resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = ImportExportForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.import_export.modules'), 'import_export', guard_url('import_export'));
            return $next($request);
        });
    }

    /**
     * Display a list of import_export.
     *
     * @return Response
     */
    public function index(ImportExportResourceRequest $request)
    {
        $request = $request->all();
        $page = ImportExportActions::run('paginate', $request);

        $data = new ImportExportsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('import_export::import_export.names'))
            ->view('import_export::import_export.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display import_export.
     *
     * @param Request $request
     * @param Model   $import_export
     *
     * @return Response
     */
    public function show(ImportExportResourceRequest $request, ImportExport $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ImportExportResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('import_export::import_export.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('import_export::import_export.show')
            ->output();
    }

    /**
     * Show the form for creating a new import_export.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ImportExportResourceRequest $request, ImportExport $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ImportExportResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('import_export::import_export.name'))
            ->view('import_export::import_export.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new import_export.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ImportExportResourceRequest $request, ImportExport $model)
    {
        try {
            $request = $request->all();
            $model = ImportExportAction::run('store', $model, $request);
            $data = new ImportExportResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('import_export::import_export.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('import_export/import_export/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/import_export/import_export'))
                ->redirect();
        }

    }

    /**
     * Show import_export for editing.
     *
     * @param Request $request
     * @param Model   $import_export
     *
     * @return Response
     */
    public function edit(ImportExportResourceRequest $request, ImportExport $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ImportExportResource($model);
        // return view('import_export::import_export.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('import_export::import_export.name'))
            ->view('import_export::import_export.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the import_export.
     *
     * @param Request $request
     * @param Model   $import_export
     *
     * @return Response
     */
    public function update(ImportExportResourceRequest $request, ImportExport $model)
    {
        try {
            $request = $request->all();
            $model = ImportExportAction::run('update', $model, $request);
            $data = new ImportExportResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('import_export::import_export.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('import_export/import_export/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('import_export/import_export/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the import_export.
     *
     * @param Model   $import_export
     *
     * @return Response
     */
    public function destroy(ImportExportResourceRequest $request, ImportExport $model)
    {
        try {

            $request = $request->all();
            $model = ImportExportAction::run('destroy', $model, $request);
            $data = new ImportExportResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('import_export::import_export.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('import_export/import_export/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('import_export/import_export/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
