<?php

namespace Bixo\ImportExport\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\ImportExport\Events\ImportExportAction as ImportExportActionEvent;
use Bixo\ImportExport\Notifications\ImportExportAction as ImportExportActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ImportExportAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ImportExportActionEvent.
     *
     * @param   ImportExportActionEvent  $event
     * @return mixed
     */
    public function handle(ImportExportActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $import_export.
     *
     * @param   ImportExportActionEvent  $event
     * @return void
     */
    public function create(ImportExportActionEvent $event)
    {
        $client = $event->import_export->client;
        Notification::send($client, new ImportExportActionNotification($event));
    }

    /**
     * Handle the ImportExportActionEvent as a listener.
     *
     * @param   ImportExportActionEvent  $event
     * @return mixed
     */
    public function asListener(ImportExportActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ImportExportActionEvent  $event
     * @return bool
     */
    private function isAllowed(ImportExportActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
